==> mapstruct-processor-1.3.0.Beta1-sources.jar: org/mapstruct/ap/internal/model/source/builtin/XmlGregorianCalendarToJodaDateTime.java <==
/*
 * Copyright MapStruct Authors.
 *
 * Licensed under the Apache License version 2.0, available at http://www.apache.org/licenses/LICENSE-2.0
 */
package org.mapstruct.ap.internal.model.source.builtin;

import static org.mapstruct.ap.internal.util.Collections.asSet;

import java.util.Set;
import javax.xml.datatype.DatatypeConstants;
import javax.xml.datatype.XMLGregorianCalendar;

import org.mapstruct.ap.internal.model.common.Parameter;
import org.mapstruct.ap.internal.model.common.Type;
import org.mapstruct.ap.internal.model.common.TypeFactory;
import org.mapstruct.ap.internal.util.JodaTimeConstants;

/**
 * @author Sjaak Derksen
 */
public class XmlGregorianCalendarToJodaDateTime extends BuiltInMethod {

    private final Parameter parameter;
    private final Type returnType;
    private final Set<Type> importTypes;

    public XmlGregorianCalendarToJodaDateTime(TypeFactory typeFactory) {
        this.parameter = new Parameter( "xcal", typeFactory.getType( XMLGregorianCalendar.class ) );
        this.returnType = typeFactory.getType( JodaTimeConstants.DATE_TIME_FQN );
        this.importTypes = asSet(
            typeFactory.getType( DatatypeConstants.class ),
            typeFactory.getType( JodaTimeConstants.DATE_TIME_ZONE_FQN ),
            returnType,
            parameter.getType() );
    }

    @Override
    public Parameter getParameter() {
        return parameter;
    }

    @Override
    public Type getReturnType() {
        return returnType;
    }

    @Override
    public Set<Type> getImportTypes() {
        return importTypes;
    }
}

==> mapstruct-processor-1.7.0.Beta1-sources.jar: org/mapstruct/ap/internal/model/source/builtin/XmlGregorianCalendarToJodaDateTime.java <==
/*
 * Copyright MapStruct Authors.
 *
 * Licensed under the Apache License version 2.0, available at http://www.apache.org/licenses/LICENSE-2.0
 */
package org.mapstruct.ap.internal.model.source.builtin;

import java.util.Calendar;
import java.util.Set;

import org.mapstruct.ap.internal.model.common.Parameter;
import org.mapstruct.ap.internal.model.common.Type;
import org.mapstruct.ap.internal.model.common.TypeFactory;
import org.mapstruct.ap.internal.util.JodaTimeConstants;
import org.mapstruct.ap.internal.util.XmlConstants;

import static org.mapstruct.ap.internal.util.Collections.asSet;

/**
 * A built-in method for converting from Joda {@code DateTime} to {@link Calendar}.
 *
 * @author Sjaak Derksen
 */
public class XmlGregorianCalendarToJodaDateTime extends BuiltInMethod {

    private final Parameter parameter;
    private final Type returnType;
    private final Set<Type> importTypes;

    public XmlGregorianCalendarToJodaDateTime(TypeFactory typeFactory) {
        this.parameter = new Parameter( "xcal", typeFactory.getType( XmlConstants.JAVAX_XML_XML_GREGORIAN_CALENDAR ) );
        this.returnType = typeFactory.getType( JodaTimeConstants.DATE_TIME_FQN );
        this.importTypes = asSet(
            typeFactory.getType( XmlConstants.JAVAX_XML_DATATYPE_CONSTANTS ),
            typeFactory.getType( JodaTimeConstants.DATE_TIME_ZONE_FQN ),
            returnType,
            parameter.getType() );
    }

    @Override
    public Parameter getParameter() {
        return parameter;
    }

    @Override
    public Type getReturnType() {
        return returnType;
    }

    @Override
    public Set<Type> getImportTypes() {
        return importTypes;
    }
}
